=============================
``cavcalc.functions.general``
=============================

.. automodule:: cavcalc.functions.general

.. currentmodule:: cavcalc.functions.general

Functions
=========

.. autosummary::
    :toctree: generated/

    fsr
	finesse
	fwhm
	pole
